@@ -70,6 +70,9 @@ char *   nautilus_ensure_unique_file_name            (const char *directory_uri,
 
 GFile *  nautilus_find_existing_uri_in_hierarchy     (GFile *location);
 
+char * nautilus_get_accel_map_file (void);
+char * nautilus_get_scripts_directory_path (void);
+
 GHashTable * nautilus_trashed_files_get_original_directories (GList *files,
 							      GList **unhandled_files);
 void nautilus_restore_files_from_trash (GList *files,
