@@ -84,9 +84,14 @@
 
 #define START_STATE_CONFIG "start-state"
 
+#define NAUTILUS_ACCEL_MAP_SAVE_DELAY 30
+
 /* Keeps track of all the desktop windows. */
 static GList *nautilus_application_desktop_windows;
 
+/* The saving of the accelerator map was requested  */
+static gboolean save_of_accel_map_requested = FALSE;
+
 static void     desktop_changed_callback          (gpointer                  user_data);
 static void     mount_removed_callback            (GVolumeMonitor            *monitor,
 						   GMount                    *mount,
@@ -565,19 +570,14 @@ mount_removed_callback (GVolumeMonitor *monitor,
 		window = NAUTILUS_WINDOW (node->data);
 		if (window != NULL && !NAUTILUS_IS_DESKTOP_WINDOW (window)) {
 			GList *l;
-			GList *lp;
 
-			for (lp = window->details->panes; lp != NULL; lp = lp->next) {
-				NautilusWindowPane *pane;
-				pane = (NautilusWindowPane*) lp->data;
-				for (l = pane->slots; l != NULL; l = l->next) {
-					slot = l->data;
-					n_slots++;
-					if (nautilus_window_slot_should_close_with_mount (slot, mount)) {
-						close_list = g_list_prepend (close_list, slot);
-					}
-				} /* for all slots */
-			} /* for all panes */
+			for (l = window->details->slots; l != NULL; l = l->next) {
+				slot = l->data;
+				n_slots++;
+				if (nautilus_window_slot_should_close_with_mount (slot, mount)) {
+					close_list = g_list_prepend (close_list, slot);
+				}
+			} /* for all slots */
 		}
 	}
 
@@ -593,11 +593,11 @@ mount_removed_callback (GVolumeMonitor *monitor,
 		slot = node->data;
 
 		if (slot != force_no_close_slot) {
-			nautilus_window_pane_slot_close (slot->pane, slot);
+			nautilus_window_slot_close (slot->window, slot);
 		} else {
 			computer = g_file_new_for_path (g_get_home_dir ());
 			nautilus_window_slot_open_location (slot, computer, 0);
-			g_object_unref(computer);
+			g_object_unref (computer);
 		}
 	}
 
@@ -1103,6 +1103,151 @@ init_desktop (NautilusApplication *self)
 				  self);
 }
 
+static gboolean 
+nautilus_application_save_accel_map (gpointer data)
+{
+	if (save_of_accel_map_requested) {
+		char *accel_map_filename;
+	 	accel_map_filename = nautilus_get_accel_map_file ();
+	 	if (accel_map_filename) {
+	 		gtk_accel_map_save (accel_map_filename);
+	 		g_free (accel_map_filename);
+	 	}
+		save_of_accel_map_requested = FALSE;
+	}
+
+	return FALSE;
+}
+
+static void 
+queue_accel_map_save_callback (GtkAccelMap *object, gchar *accel_path,
+		guint accel_key, GdkModifierType accel_mods,
+		gpointer user_data)
+{
+	if (!save_of_accel_map_requested) {
+		save_of_accel_map_requested = TRUE;
+		g_timeout_add_seconds (NAUTILUS_ACCEL_MAP_SAVE_DELAY, 
+				nautilus_application_save_accel_map, NULL);
+	}
+}
+
+static void
+update_accel_due_to_scripts_migration (gpointer data, const gchar *accel_path, guint accel_key,
+		GdkModifierType accel_mods, gboolean changed)
+{
+	char *old_scripts_location_esc = data;
+	char *old_scripts_pt;
+
+	old_scripts_pt = strstr (accel_path, old_scripts_location_esc);
+
+	if (old_scripts_pt != NULL) {
+		/* There's a mention of the deprecated scripts directory in the accel. Remove it, and
+		 * add a migrated one. */
+		char *tmp;
+		char *tmp2;
+		GString *new_accel_path;
+
+		/* base part of accel */
+		tmp = g_strndup (accel_path, old_scripts_pt - accel_path);
+		new_accel_path = g_string_new (tmp);
+		g_free (tmp);
+
+		/* new script directory, escaped */
+		tmp = nautilus_get_scripts_directory_path ();
+		tmp2 = nautilus_escape_action_name (tmp, "");
+		g_free (tmp);
+		g_string_append (new_accel_path, tmp2);
+		g_free (tmp2);
+
+		/* script path relative to scripts directory */
+		g_string_append (new_accel_path, old_scripts_pt + strlen (old_scripts_location_esc));
+
+		/* exchange entry */
+		gtk_accel_map_change_entry (accel_path, 0, 0, FALSE);
+		gtk_accel_map_change_entry (new_accel_path->str, accel_key, accel_mods, TRUE);
+
+		g_string_free (new_accel_path, TRUE);
+	}
+}
+
+static void
+init_gtk_accels (void)
+{
+	char *accel_map_filename;
+	gboolean performed_migration = FALSE;
+	char *old_scripts_directory_path = NULL;
+
+	accel_map_filename = nautilus_get_accel_map_file ();
+
+	/* If the accel map file doesn't exist, try to migrate from
+	 * former locations. */
+	if (!g_file_test (accel_map_filename, G_FILE_TEST_IS_REGULAR)) {
+		char *old_accel_map_filename;
+		const gchar *override;
+
+		override = g_getenv ("GNOME22_USER_DIR");
+		if (override) {
+			old_accel_map_filename = g_build_filename (override,
+					"accels", "nautilus", NULL);
+			old_scripts_directory_path = g_build_filename (override,
+				       "nautilus-scripts",
+				       NULL);
+		} else {
+			old_accel_map_filename = g_build_filename (g_get_home_dir (),
+					".gnome2", "accels", "nautilus", NULL);
+			old_scripts_directory_path = g_build_filename (g_get_home_dir (),
+								       ".gnome2",
+								       "nautilus-scripts",
+								       NULL);
+		}
+
+		if (g_file_test (old_accel_map_filename, G_FILE_TEST_IS_REGULAR)) {
+			char *parent_dir;
+
+			parent_dir = g_path_get_dirname (accel_map_filename);
+			if (g_mkdir_with_parents (parent_dir, 0700) == 0) {
+				GFile *accel_map_file;
+				GFile *old_accel_map_file;
+
+				accel_map_file = g_file_new_for_path (accel_map_filename);
+				old_accel_map_file = g_file_new_for_path (old_accel_map_filename);
+
+				/* If the move fails, it's safer to not read any accel map
+				 * on startup instead of reading the old one and possibly
+				 * being stuck with it. */
+				performed_migration = g_file_move (old_accel_map_file, accel_map_file, 0, NULL, NULL, NULL, NULL);
+
+				g_object_unref (accel_map_file);
+				g_object_unref (old_accel_map_file);
+			}
+			g_free (parent_dir);
+		}
+
+		g_free (old_accel_map_filename);
+	}
+
+	/* load accelerator map, and register save callback */
+	gtk_accel_map_load (accel_map_filename);
+	g_free (accel_map_filename);
+
+	if (performed_migration) {
+		/* Migrate accels pointing to scripts */
+		char *old_scripts_location_esc;
+
+		old_scripts_location_esc = nautilus_escape_action_name (old_scripts_directory_path, "");
+		gtk_accel_map_foreach (old_scripts_location_esc, update_accel_due_to_scripts_migration);
+		g_free (old_scripts_location_esc);
+		/* save map immediately */
+		save_of_accel_map_requested = TRUE;
+		nautilus_application_save_accel_map (NULL);
+	}
+
+	g_signal_connect (gtk_accel_map_get (), "changed",
+			  G_CALLBACK (queue_accel_map_save_callback), NULL);
+
+	g_free (old_scripts_directory_path);
+}
+
 static void
 nautilus_application_startup (GApplication *app)
 {
@@ -1127,7 +1272,6 @@ nautilus_application_startup (GApplication *app)
 	nautilus_icon_view_register ();
 	nautilus_desktop_icon_view_register ();
 	nautilus_list_view_register ();
-	nautilus_icon_view_compact_register ();
 #if ENABLE_EMPTY_VIEW
 	nautilus_empty_view_register ();
 #endif
@@ -1137,6 +1281,7 @@ nautilus_application_startup (GApplication *app)
 
 	/* initialize theming */
 	init_icons_and_styles ();
+	init_gtk_accels ();
 	
 	/* initialize nautilus modules */
 	nautilus_module_setup ();
@@ -1173,6 +1318,7 @@ nautilus_application_quit_mainloop (GApplication *app)
 	DEBUG ("Quitting mainloop");
 
 	nautilus_icon_info_clear_caches ();
+ 	nautilus_application_save_accel_map (NULL);
 
 	G_APPLICATION_CLASS (nautilus_application_parent_class)->quit_mainloop (app);
 }
