@@ -28,8 +28,6 @@
 #include <gio/gio.h>
 #include <gtk/gtk.h>
 
-#include <libnautilus-private/nautilus-undo-manager.h>
-
 #include "nautilus-window.h"
 
 #define NAUTILUS_DESKTOP_ICON_VIEW_IID	"OAFIID:Nautilus_File_Manager_Desktop_Icon_View"
@@ -56,8 +54,6 @@ typedef struct _NautilusApplicationPriv NautilusApplicationPriv;
 typedef struct {
 	GtkApplication parent;
 
-	NautilusUndoManager *undo_manager;
-
 	NautilusApplicationPriv *priv;
 } NautilusApplication;
 
@@ -67,10 +63,6 @@ typedef struct {
 
 GType nautilus_application_get_type (void);
 
-NautilusApplication *nautilus_application_get_singleton (void);
-
-void nautilus_application_quit (NautilusApplication *self);
-
 NautilusWindow *     nautilus_application_create_window (NautilusApplication *application,
 							 GdkScreen           *screen);
 
@@ -79,6 +71,4 @@ void nautilus_application_open_location (NautilusApplication *application,
 					 GFile *selection,
 					 const char *startup_id);
 
-void nautilus_application_close_all_windows (NautilusApplication *self);
-
 #endif /* __NAUTILUS_APPLICATION_H__ */
