@@ -143,6 +143,7 @@ append_label (GtkWidget *vbox,
 	 * selectable but without the cursor showing.
 	 */
 	gtk_widget_set_can_focus (label, FALSE);
+	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
 
 	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
 	gtk_widget_show (label);
@@ -446,7 +447,7 @@ file_read_callback (GObject      *object,
 
 #ifdef HAVE_EXIF
 		exif_still_loading = exif_loader_write (page->details->exifldr,
-				  		        page->details->buffer,
+				  		        (guchar *) page->details->buffer,
 				  			count_read);
 #else
 		exif_still_loading = 0;
@@ -454,7 +455,7 @@ file_read_callback (GObject      *object,
 
 		if (page->details->pixbuf_still_loading) {
 			if (!gdk_pixbuf_loader_write (page->details->loader,
-					      	      page->details->buffer,
+					      	      (const guchar *) page->details->buffer,
 					      	      count_read,
 					      	      NULL)) {
 				page->details->pixbuf_still_loading = FALSE;
