@@ -32,7 +32,6 @@
 #include <libnautilus-private/nautilus-dnd.h>
 #include <libnautilus-private/nautilus-bookmark.h>
 #include <libnautilus-private/nautilus-global-preferences.h>
-#include <libnautilus-private/nautilus-module.h>
 #include <libnautilus-private/nautilus-file.h>
 #include <libnautilus-private/nautilus-file-utilities.h>
 #include <libnautilus-private/nautilus-file-operations.h>
@@ -170,8 +169,8 @@ static void bookmarks_check_popup_sensitivity          (NautilusPlacesSidebar *s
 
 /* Identifiers for target types */
 enum {
-  GTK_TREE_MODEL_ROW,
-  TEXT_URI_LIST
+	GTK_TREE_MODEL_ROW,
+	TEXT_URI_LIST
 };
 
 /* Target types for dragging from the shortcuts list */
@@ -187,18 +186,15 @@ static const GtkTargetEntry nautilus_shortcuts_drop_targets [] = {
 
 /* Drag and drop interface declarations */
 typedef struct {
-  GtkListStore parent;
+	GtkListStore parent;
 
-  NautilusPlacesSidebar *sidebar;
+	NautilusPlacesSidebar *sidebar;
 } NautilusShortcutsModel;
 
 typedef struct {
-  GtkListStoreClass parent_class;
+	GtkListStoreClass parent_class;
 } NautilusShortcutsModelClass;
 
-#define NAUTILUS_TYPE_SHORTCUTS_MODEL (_nautilus_shortcuts_model_get_type ())
-#define NAUTILUS_SHORTCUTS_MODEL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), NAUTILUS_SHORTCUTS_MODEL_TYPE, NautilusShortcutsModel))
-
 GType _nautilus_shortcuts_model_get_type (void);
 static void _nautilus_shortcuts_model_drag_source_init (GtkTreeDragSourceIface *iface);
 G_DEFINE_TYPE_WITH_CODE (NautilusShortcutsModel, _nautilus_shortcuts_model, GTK_TYPE_LIST_STORE,
@@ -1074,12 +1070,12 @@ loading_uri_callback (NautilusWindow *window,
 
 /* Computes the appropriate row and position for dropping */
 static gboolean
-compute_drop_position (GtkTreeView *tree_view,
+compute_drop_position (GtkTreeView             *tree_view,
 		       int                      x,
 		       int                      y,
 		       GtkTreePath            **path,
 		       GtkTreeViewDropPosition *pos,
-		       NautilusPlacesSidebar *sidebar)
+		       NautilusPlacesSidebar   *sidebar)
 {
 	GtkTreeModel *model;
 	GtkTreeIter iter;
@@ -1100,11 +1096,12 @@ compute_drop_position (GtkTreeView *tree_view,
 			    PLACES_SIDEBAR_COLUMN_SECTION_TYPE, &section_type,
 			    -1);
 
-	if (place_type == PLACES_HEADING && section_type != SECTION_BOOKMARKS) {
+	if (section_type != SECTION_BOOKMARKS &&
+	    place_type == PLACES_HEADING) {
 		/* never drop on headings, but special case the bookmarks heading,
-		 * so we can drop bookmarks in between it and the first item.
+		 * so we can drop bookmarks in between it and the first item when
+		 * reordering.
 		 */
-
 		gtk_tree_path_free (*path);
 		*path = NULL;
 		
@@ -1115,27 +1112,20 @@ compute_drop_position (GtkTreeView *tree_view,
 	    sidebar->drag_data_received &&
 	    sidebar->drag_data_info == GTK_TREE_MODEL_ROW) {
 		/* don't allow dropping bookmarks into non-bookmark areas */
-
 		gtk_tree_path_free (*path);
 		*path = NULL;
 
 		return FALSE;
 	}
 
-	if (section_type == SECTION_BOOKMARKS) {
+	if (sidebar->drag_data_received &&
+	    sidebar->drag_data_info == GTK_TREE_MODEL_ROW) {
+		/* bookmark rows can only be reordered */
 		*pos = GTK_TREE_VIEW_DROP_AFTER;
 	} else {
-		/* non-bookmark shortcuts can only be dragged into */
 		*pos = GTK_TREE_VIEW_DROP_INTO_OR_BEFORE;
 	}
 
-	if (*pos != GTK_TREE_VIEW_DROP_BEFORE &&
-	    sidebar->drag_data_received &&
-	    sidebar->drag_data_info == GTK_TREE_MODEL_ROW) {
-		/* bookmark rows are never dragged into other bookmark rows */
-		*pos = GTK_TREE_VIEW_DROP_AFTER;
-	}
-
 	return TRUE;
 }
 
@@ -1171,36 +1161,6 @@ free_drag_data (NautilusPlacesSidebar *sidebar)
 	}
 }
 
-static gboolean
-can_accept_file_as_bookmark (NautilusFile *file)
-{
-	return (nautilus_file_is_directory (file) &&
-		!is_built_in_bookmark (file));
-}
-
-static gboolean
-can_accept_items_as_bookmarks (const GList *items)
-{
-	int max;
-	char *uri;
-	NautilusFile *file;
-
-	/* Iterate through selection checking if item will get accepted as a bookmark.
-	 * If more than 100 items selected, return an over-optimistic result.
-	 */
-	for (max = 100; items != NULL && max >= 0; items = items->next, max--) {
-		uri = ((NautilusDragSelectionItem *)items->data)->uri;
-		file = nautilus_file_get_by_uri (uri);
-		if (!can_accept_file_as_bookmark (file)) {
-			nautilus_file_unref (file);
-			return FALSE;
-		}
-		nautilus_file_unref (file);
-	}
-	
-	return TRUE;
-}
-
 static gboolean
 drag_motion_callback (GtkTreeView *tree_view,
 		      GdkDragContext *context,
@@ -1229,13 +1189,10 @@ drag_motion_callback (GtkTreeView *tree_view,
 		goto out;
 	}
 
-	if (pos == GTK_TREE_VIEW_DROP_BEFORE ||
-	    pos == GTK_TREE_VIEW_DROP_AFTER ) {
+	if (pos == GTK_TREE_VIEW_DROP_AFTER ) {
 		if (sidebar->drag_data_received &&
 		    sidebar->drag_data_info == GTK_TREE_MODEL_ROW) {
 			action = GDK_ACTION_MOVE;
-		} else if (can_accept_items_as_bookmarks (sidebar->drag_list)) {
-			action = GDK_ACTION_COPY;
 		} else {
 			action = 0;
 		}
@@ -1283,54 +1240,10 @@ drag_leave_callback (GtkTreeView *tree_view,
 		     NautilusPlacesSidebar *sidebar)
 {
 	free_drag_data (sidebar);
-	gtk_tree_view_set_drag_dest_row (tree_view, NULL, GTK_TREE_VIEW_DROP_BEFORE);
+	gtk_tree_view_set_drag_dest_row (tree_view, NULL, 0);
 	g_signal_stop_emission_by_name (tree_view, "drag-leave");
 }
 
-/* Parses a "text/uri-list" string and inserts its URIs as bookmarks */
-static void
-bookmarks_drop_uris (NautilusPlacesSidebar *sidebar,
-		     GtkSelectionData      *selection_data,
-		     int                    position)
-{
-	NautilusBookmark *bookmark;
-	NautilusFile *file;
-	char *uri;
-	char **uris;
-	int i;
-	GFile *location;
-	
-	uris = gtk_selection_data_get_uris (selection_data);
-	if (!uris)
-		return;
-	
-	for (i = 0; uris[i]; i++) {
-		uri = uris[i];
-		file = nautilus_file_get_by_uri (uri);
-
-		if (!can_accept_file_as_bookmark (file)) {
-			nautilus_file_unref (file);
-			continue;
-		}
-
-		uri = nautilus_file_get_drop_target_uri (file);
-		location = g_file_new_for_uri (uri);
-		nautilus_file_unref (file);
-
-		bookmark = nautilus_bookmark_new (location, NULL, NULL);
-
-		if (!nautilus_bookmark_list_contains (sidebar->bookmarks, bookmark)) {
-			nautilus_bookmark_list_insert_item (sidebar->bookmarks, bookmark, position++);
-		}
-
-		g_object_unref (location);
-		g_object_unref (bookmark);
-		g_free (uri);
-	}
-
-	g_strfreev (uris);
-}
-
 static GList *
 uri_list_from_selection (GList *selection)
 {
@@ -1461,8 +1374,7 @@ drag_data_received_callback (GtkWidget *widget,
 
 	success = FALSE;
 
-	if (tree_pos == GTK_TREE_VIEW_DROP_BEFORE ||
-	    tree_pos == GTK_TREE_VIEW_DROP_AFTER) {
+	if (tree_pos == GTK_TREE_VIEW_DROP_AFTER) {
 		model = gtk_tree_view_get_model (tree_view);
 
 		if (!gtk_tree_model_get_iter (model, &iter, tree_path)) {
@@ -1485,10 +1397,6 @@ drag_data_received_callback (GtkWidget *widget,
 		}
 
 		switch (info) {
-		case TEXT_URI_LIST:
-			bookmarks_drop_uris (sidebar, selection_data, position);
-			success = TRUE;
-			break;
 		case GTK_TREE_MODEL_ROW:
 			reorder_bookmarks (sidebar, position);
 			success = TRUE;
@@ -1806,6 +1714,7 @@ volume_mounted_cb (GVolume *volume,
 	if (sidebar->go_to_after_mount_slot) {
 		g_object_remove_weak_pointer (G_OBJECT (sidebar->go_to_after_mount_slot),
 					      (gpointer *) &sidebar->go_to_after_mount_slot);
+		sidebar->go_to_after_mount_slot = NULL;
 	}
 }
 
@@ -3625,7 +3534,7 @@ nautilus_shortcuts_model_new (NautilusPlacesSidebar *sidebar)
 		G_TYPE_STRING
 	};
 
-	model = g_object_new (NAUTILUS_TYPE_SHORTCUTS_MODEL, NULL);
+	model = g_object_new (_nautilus_shortcuts_model_get_type (), NULL);
 	model->sidebar = sidebar;
 
 	gtk_list_store_set_column_types (GTK_LIST_STORE (model),
