@@ -37,6 +37,7 @@
 #include "nautilus-window-private.h"
 #include "nautilus-window-slot.h"
 #include "nautilus-trash-bar.h"
+#include "nautilus-toolbar.h"
 #include "nautilus-view-factory.h"
 #include "nautilus-x-content-bar.h"
 #include <eel/eel-accessibility.h>
@@ -265,7 +266,7 @@ viewed_file_changed_callback (NautilusFile *file,
 	gboolean is_in_trash, was_in_trash;
 
         g_assert (NAUTILUS_IS_FILE (file));
-	g_assert (NAUTILUS_IS_WINDOW_PANE (slot->pane));
+	g_assert (NAUTILUS_IS_WINDOW (slot->window));
 	g_assert (file == slot->viewed_file);
 
         if (!nautilus_file_is_not_yet_confirmed (file)) {
@@ -313,11 +314,14 @@ viewed_file_changed_callback (NautilusFile *file,
 				/* the path bar URI will be set to go_to_uri immediately
 				 * in begin_location_change, but we don't want the
 				 * inexistant children to show up anymore */
-				if (slot == slot->pane->active_slot) {
+				if (slot == slot->window->details->active_slot) {
+					GtkWidget *path_bar;
+
 					/* multiview-TODO also update NautilusWindowSlot
 					 * [which as of writing doesn't save/store any path bar state]
 					 */
-					nautilus_path_bar_clear_buttons (NAUTILUS_PATH_BAR (slot->pane->path_bar));
+					path_bar = nautilus_toolbar_get_path_bar (NAUTILUS_TOOLBAR (slot->window->details->toolbar));
+					nautilus_path_bar_clear_buttons (NAUTILUS_PATH_BAR (path_bar));
 				}
 				
 				nautilus_window_slot_open_location (slot, go_to_file, 0);
@@ -335,8 +339,8 @@ viewed_file_changed_callback (NautilusFile *file,
 				   slot->location)) {
                         g_object_unref (slot->location);
                         slot->location = new_location;
-			if (slot == slot->pane->active_slot) {
-				nautilus_window_pane_sync_location_widgets (slot->pane);
+			if (slot == slot->window->details->active_slot) {
+				nautilus_window_sync_location_widgets (slot->window);
 			}
                 } else {
 			/* TODO?
@@ -408,13 +412,11 @@ nautilus_window_slot_open_location_full (NautilusWindowSlot *slot,
 {
 	NautilusWindow *window;
         NautilusWindow *target_window;
-        NautilusWindowPane *pane;
         NautilusWindowSlot *target_slot;
 	NautilusWindowOpenFlags slot_flags;
 	GFile *old_location;
 	char *old_uri, *new_uri;
 	int new_slot_position;
-	GList *l;
 	gboolean use_same;
 	gboolean is_desktop;
 
@@ -485,8 +487,8 @@ nautilus_window_slot_open_location_full (NautilusWindowSlot *slot,
 			slot_flags = NAUTILUS_WINDOW_OPEN_SLOT_APPEND;
 		}
 
-		target_slot = nautilus_window_pane_open_slot (nautilus_window_get_active_pane (window),
-							      slot_flags);
+		target_slot = nautilus_window_open_slot (window,
+							 slot_flags);
 	}
 
 	/* close the current window if the flags say so */
@@ -527,17 +529,6 @@ nautilus_window_slot_open_location_full (NautilusWindowSlot *slot,
         begin_location_change (target_slot, location, old_location, new_selection,
 			       NAUTILUS_LOCATION_CHANGE_STANDARD, 0, NULL, callback, user_data);
 
-	/* Additionally, load this in all slots that have no location, this means
-	   we load both panes in e.g. a newly opened dual pane window. */
-	for (l = target_window->details->panes; l != NULL; l = l->next) {
-		pane = l->data;
-		slot = pane->active_slot;
-		if (slot->location == NULL && slot->pending_location == NULL) {
-			begin_location_change (slot, location, old_location, new_selection,
-					       NAUTILUS_LOCATION_CHANGE_STANDARD, 0, NULL, NULL, NULL);
-		}
-	}
-
 	g_clear_object (&old_location);
 }
 
@@ -766,7 +757,7 @@ got_file_info_for_view_selection_callback (NautilusFile *file,
 	char *mimetype;
 	NautilusWindow *window;
 	NautilusWindowSlot *slot;
-	NautilusFile *viewed_file;
+	NautilusFile *viewed_file, *parent_file;
 	GFile *location;
 	GMountOperation *mount_op;
 	MountNotMountedData *data;
@@ -805,7 +796,9 @@ got_file_info_for_view_selection_callback (NautilusFile *file,
 		return;
 	}
 
-	if (nautilus_file_get_file_type (file) == G_FILE_TYPE_REGULAR) {
+	parent_file = nautilus_file_get_parent (file);
+	if ((parent_file != NULL) &&
+	    nautilus_file_get_file_type (file) == G_FILE_TYPE_REGULAR) {
 		if (slot->pending_selection != NULL) {
 			g_list_free_full (slot->pending_selection, (GDestroyNotify) nautilus_file_unref);
 		}
@@ -815,7 +808,7 @@ got_file_info_for_view_selection_callback (NautilusFile *file,
 	
 		slot->pending_location = nautilus_file_get_parent_location (file);
 		slot->pending_selection = g_list_prepend (NULL, nautilus_file_ref (file));
-		slot->determine_view_file = nautilus_file_get_parent (file);
+		slot->determine_view_file = parent_file;
 		slot->pending_scroll_to = nautilus_file_get_uri (file);
 
 		nautilus_file_invalidate_all_attributes (slot->determine_view_file);
@@ -829,6 +822,7 @@ got_file_info_for_view_selection_callback (NautilusFile *file,
 		return;
 	}
 
+	nautilus_file_unref (parent_file);
 	location = slot->pending_location;
 	
 	view_id = NULL;
@@ -921,7 +915,7 @@ got_file_info_for_view_selection_callback (NautilusFile *file,
 			/* We're missing a previous location (if opened location
 			 * in a new tab) so close it and return */
 			if (slot->location == NULL) {
-				nautilus_window_pane_slot_close (slot->pane, slot);
+				nautilus_window_slot_close (slot->window, slot);
 			} else {
 				/* We disconnected this, so we need to re-connect it */
 				viewed_file = nautilus_file_get (slot->location);
@@ -1244,33 +1238,13 @@ slot_add_extension_extra_widgets (NautilusWindowSlot *slot)
 static void
 nautilus_window_slot_show_x_content_bar (NautilusWindowSlot *slot, GMount *mount, const char **x_content_types)
 {
-	unsigned int n;
+	GtkWidget *bar;
 
 	g_assert (NAUTILUS_IS_WINDOW_SLOT (slot));
 
-	for (n = 0; x_content_types[n] != NULL; n++) {
-		GAppInfo *default_app;
-
-		/* skip blank media; the burn:/// location will provide it's own cluebar */
-		if (g_str_has_prefix (x_content_types[n], "x-content/blank-")) {
-			continue;
-		}
-
-		/* don't show the cluebar for windows software */
-		if (g_content_type_is_a (x_content_types[n], "x-content/win32-software")) {
-			continue;
-		}
-
-		/* only show the cluebar if a default app is available */
-		default_app = g_app_info_get_default_for_type (x_content_types[n], FALSE);
-		if (default_app != NULL)  {
-			GtkWidget *bar;
-			bar = nautilus_x_content_bar_new (mount, x_content_types[n]);
-			gtk_widget_show (bar);
-			nautilus_window_slot_add_extra_location_widget (slot, bar);
-			g_object_unref (default_app);
-		}
-	}
+	bar = nautilus_x_content_bar_new (mount, x_content_types);
+	gtk_widget_show (bar);
+	nautilus_window_slot_add_extra_location_widget (slot, bar);
 }
 
 static void
@@ -1437,11 +1411,11 @@ update_for_new_location (NautilusWindowSlot *slot)
 	nautilus_window_slot_update_title (slot);
 	nautilus_window_slot_update_icon (slot);
 
-	if (slot == slot->pane->active_slot) {
-		nautilus_window_pane_sync_location_widgets (slot->pane);
+	if (slot == slot->window->details->active_slot) {
+		nautilus_window_sync_location_widgets (slot->window);
 
 		if (location_really_changed) {
-			nautilus_window_pane_sync_search_widgets (slot->pane);
+			nautilus_window_sync_search_widgets (slot->window);
 		}
 	}
 }
