@@ -21,9 +21,13 @@
   
    Author: Christian Neumair <cneumair@gnome.org>
 */
+
+#include "config.h"
+
 #include "nautilus-window-slot.h"
 
 #include "nautilus-desktop-window.h"
+#include "nautilus-toolbar.h"
 #include "nautilus-floating-bar.h"
 #include "nautilus-window-private.h"
 #include "nautilus-window-manage-views.h"
@@ -78,7 +82,7 @@ real_update_query_editor (NautilusWindowSlot *slot)
 	gboolean slot_is_active;
 	NautilusWindow *window;
 
-	window = nautilus_window_slot_get_window (slot);
+	window = slot->window;
 	query_editor = NULL;
 	slot_is_active = (slot == nautilus_window_get_active_slot (window));
 
@@ -88,11 +92,14 @@ real_update_query_editor (NautilusWindowSlot *slot)
 
 		if (nautilus_search_directory_is_saved_search (search_directory)) {
 			query_editor = nautilus_query_editor_new (TRUE);
-			nautilus_window_pane_sync_search_widgets (slot->pane);
+			nautilus_window_sync_search_widgets (window);
 		} else {
+			GtkWidget *search_bar;
+
+			search_bar = nautilus_toolbar_get_search_bar (NAUTILUS_TOOLBAR (window->details->toolbar));
 			query_editor = nautilus_query_editor_new_with_bar (FALSE,
 									   slot_is_active,
-									   NAUTILUS_SEARCH_BAR (slot->pane->search_bar),
+									   NAUTILUS_SEARCH_BAR (search_bar),
 									   slot);
 		}
 	}
@@ -127,24 +134,21 @@ static void
 real_active (NautilusWindowSlot *slot)
 {
 	NautilusWindow *window;
-	NautilusWindowPane *pane;
 	int page_num;
 
-	window = nautilus_window_slot_get_window (slot);
-	pane = slot->pane;
-	page_num = gtk_notebook_page_num (GTK_NOTEBOOK (pane->notebook),
+	window = slot->window;
+	page_num = gtk_notebook_page_num (GTK_NOTEBOOK (window->details->notebook),
 					  GTK_WIDGET (slot));
 	g_assert (page_num >= 0);
 
-	gtk_notebook_set_current_page (GTK_NOTEBOOK (pane->notebook), page_num);
+	gtk_notebook_set_current_page (GTK_NOTEBOOK (window->details->notebook), page_num);
 
 	/* sync window to new slot */
-	nautilus_window_push_status (window, slot->status_text);
 	nautilus_window_sync_allow_stop (window, slot);
 	nautilus_window_sync_title (window, slot);
 	nautilus_window_sync_zoom_widgets (window);
-	nautilus_window_pane_sync_location_widgets (slot->pane);
-	nautilus_window_pane_sync_search_widgets (slot->pane);
+	nautilus_window_sync_location_widgets (window);
+	nautilus_window_sync_search_widgets (window);
 
 	if (slot->viewed_file != NULL) {
 		nautilus_window_load_view_as_menus (window);
@@ -178,7 +182,6 @@ nautilus_window_slot_init (NautilusWindowSlot *slot)
 
 	gtk_orientable_set_orientation (GTK_ORIENTABLE (slot),
 					GTK_ORIENTATION_VERTICAL);
-	gtk_widget_show (GTK_WIDGET (slot));
 
 	extras_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
 	slot->extra_location_widgets = extras_vbox;
@@ -261,7 +264,7 @@ nautilus_window_slot_dispose (GObject *object)
 		slot->find_mount_cancellable = NULL;
 	}
 
-	slot->pane = NULL;
+	slot->window = NULL;
 
 	g_free (slot->title);
 	slot->title = NULL;
@@ -324,9 +327,9 @@ nautilus_window_slot_get_location_uri (NautilusWindowSlot *slot)
 }
 
 void
-nautilus_window_slot_make_hosting_pane_active (NautilusWindowSlot *slot)
+nautilus_window_slot_make_hosting_window_active (NautilusWindowSlot *slot)
 {
-	g_assert (NAUTILUS_IS_WINDOW_PANE (slot->pane));
+	g_assert (NAUTILUS_IS_WINDOW_SLOT (slot));
 	
 	nautilus_window_set_active_slot (nautilus_window_slot_get_window (slot),
 					 slot);
@@ -336,7 +339,7 @@ NautilusWindow *
 nautilus_window_slot_get_window (NautilusWindowSlot *slot)
 {
 	g_assert (NAUTILUS_IS_WINDOW_SLOT (slot));
-	return slot->pane->window;
+	return slot->window;
 }
 
 /* nautilus_window_slot_update_title:
@@ -469,22 +472,17 @@ static void
 real_slot_set_short_status (NautilusWindowSlot *slot,
 			    const gchar *status)
 {
-	
-	gboolean show_statusbar;
 	gboolean disable_chrome;
 
 	nautilus_floating_bar_cleanup_actions (NAUTILUS_FLOATING_BAR (slot->floating_bar));
 	nautilus_floating_bar_set_show_spinner (NAUTILUS_FLOATING_BAR (slot->floating_bar),
 						FALSE);
 
-	show_statusbar = g_settings_get_boolean (nautilus_window_state,
-						 NAUTILUS_WINDOW_STATE_START_WITH_STATUS_BAR);
-
 	g_object_get (nautilus_window_slot_get_window (slot),
 		      "disable-chrome", &disable_chrome,
 		      NULL);
 
-	if (status == NULL || show_statusbar || disable_chrome) {
+	if (status == NULL || disable_chrome) {
 		gtk_widget_hide (slot->floating_bar);
 		return;
 	}
@@ -558,8 +556,6 @@ nautilus_window_slot_set_status (NautilusWindowSlot *slot,
 				 const char *status,
 				 const char *short_status)
 {
-	NautilusWindow *window;
-
 	g_assert (NAUTILUS_IS_WINDOW_SLOT (slot));
 
 	g_free (slot->status_text);
@@ -568,11 +564,6 @@ nautilus_window_slot_set_status (NautilusWindowSlot *slot,
 	if (slot->content_view != NULL) {
 		set_floating_bar_status (slot, short_status);
 	}
-
-	window = nautilus_window_slot_get_window (slot);
-	if (slot == nautilus_window_get_active_slot (window)) {
-		nautilus_window_push_status (window, slot->status_text);
-	}
 }
 
 /* nautilus_window_slot_update_query_editor:
@@ -717,12 +708,12 @@ nautilus_window_slot_should_close_with_mount (NautilusWindowSlot *slot,
 }
 
 NautilusWindowSlot *
-nautilus_window_slot_new (NautilusWindowPane *pane)
+nautilus_window_slot_new (NautilusWindow *window)
 {
 	NautilusWindowSlot *slot;
 
 	slot = g_object_new (NAUTILUS_TYPE_WINDOW_SLOT, NULL);
-	slot->pane = pane;
+	slot->window = window;
 
 	return slot;
 }
