@@ -51,17 +51,13 @@ struct NautilusWindowSlotClass {
 	void (* inactive) (NautilusWindowSlot *slot);
 };
 
-/* Each NautilusWindowSlot corresponds to
- * a location in the window for displaying
- * a NautilusView.
- *
- * For navigation windows, this would be a
- * tab, while spatial windows only have one slot.
+/* Each NautilusWindowSlot corresponds to a location in the window
+ * for displaying a NautilusView, i.e. a tab.
  */
 struct NautilusWindowSlot {
 	GtkBox parent;
 
-	NautilusWindowPane *pane;
+	NautilusWindow *window;
 
 	/* slot contains
  	 *  1) an event box containing extra_location_widgets
@@ -110,8 +106,6 @@ struct NautilusWindowSlot {
 
 	GCancellable *find_mount_cancellable;
 
-	gboolean visible;
-
 	/* Back/Forward chain, and history list. 
 	 * The data in these lists are NautilusBookmark pointers. 
 	 */
@@ -120,7 +114,7 @@ struct NautilusWindowSlot {
 
 GType   nautilus_window_slot_get_type (void);
 
-NautilusWindowSlot * nautilus_window_slot_new (NautilusWindowPane *pane);
+NautilusWindowSlot * nautilus_window_slot_new (NautilusWindow *window);
 
 void    nautilus_window_slot_update_title		   (NautilusWindowSlot *slot);
 void    nautilus_window_slot_update_icon		   (NautilusWindowSlot *slot);
@@ -172,7 +166,7 @@ void    nautilus_window_slot_remove_extra_location_widgets (NautilusWindowSlot *
 NautilusView * nautilus_window_slot_get_current_view     (NautilusWindowSlot *slot);
 char           * nautilus_window_slot_get_current_uri      (NautilusWindowSlot *slot);
 NautilusWindow * nautilus_window_slot_get_window           (NautilusWindowSlot *slot);
-void           nautilus_window_slot_make_hosting_pane_active (NautilusWindowSlot *slot);
+void           nautilus_window_slot_make_hosting_window_active (NautilusWindowSlot *slot);
 
 gboolean nautilus_window_slot_should_close_with_mount (NautilusWindowSlot *slot,
 						       GMount *mount);
